#
# spec file for package planner
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define build_eds 0%{?suse_version} <= 1220
%define build_eds_backend 0%{?suse_version} <= 1130

Name:           planner
Version:        0.14.6
Release:        19.16
# FIXME: on update to new version, check if we can reenable eds and the eds backend
Summary:        Project Management Application for GNOME
License:        GPL-2.0+
Group:          Productivity/Office/Management
Url:            http://live.gnome.org/Planner
Source:         http://download.gnome.org/sources/planner/0.14/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM planner-cmdline.patch bnc#774972 bgo#656372 dimstar@opensuse.org -- Fix for broken "open file on startup" behaviour
Patch0:         planner-cmdline.patch
# PATCH-FIX-UPSTREAM planner-libgnome.patch bgo#681497 bnc#775189 dimstar@opensuse.org -- Link libsql-plugin to libgnome.
Patch1:         planner-libgnome.patch
# PATCH-FIX-UPSTREAM planner-gtk-1.25.patch dimstar@opensuse.org -- Do not install non-existing index.sgml
Patch2:         planner-gtk-1.25.patch
%if %build_eds
BuildRequires:  evolution-data-server-devel
%if %build_eds_backend
BuildRequires:  evolution-devel
%endif
%endif
BuildRequires:  fdupes
BuildRequires:  gnome-common
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libglade2-devel
BuildRequires:  libgnomecanvas-devel
BuildRequires:  libgnomeui-devel
BuildRequires:  libxslt-devel >= 1.1.23
BuildRequires:  python-devel
BuildRequires:  python-gtk-devel
BuildRequires:  rarian-scrollkeeper-compat
# We need the %%mime_database_* macros
BuildRequires:  shared-mime-info
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
Requires:       gnome-icon-theme
Requires:       python-gtk
Recommends:     %{name}-lang
Provides:       mrproject
Obsoletes:      mrproject <= 0.10
%if ! (%build_eds)
# In case we don't build the evolution sub-package, we need to obsolete it for clean upgrade paths.
Obsoletes:      %{name}-evolution <= %{version}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%gconf_schemas_prereq
%py_requires

%description
Planner is a project management tool for the GNOME desktop, for
planning, scheduling and tracking projects.

%if %build_eds
%package evolution
Summary:        Planner integration with Evolution
Group:          Productivity/Office/Management
Requires:       %{name} = %{version}
Supplements:    packageand(planner:evolution)

%description evolution
Planner is a project management tool for the GNOME desktop, for
planning, scheduling and tracking projects.
%endif

%package devel
Summary:        Project Management Application for GNOME
Group:          Productivity/Office/Management
Requires:       %{name} = %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description devel
Planner is a project management tool for the GNOME desktop, for
planning, scheduling and tracking projects.

%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
translation-update-upstream

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure --disable-static --with-pic \
    --disable-schemas-install \
    --disable-scrollkeeper \
    --disable-update-mimedb \
    --enable-gtk-doc \
    --with-database=no \
    --enable-python \
    --enable-python-plugin \
%if %build_eds
    --enable-eds \
%else
    --disable-eds \
%endif
%if %build_eds_backend
    --enable-eds-backend
%else
    --disable-eds-backend
%endif
make %{?jobs:-j%jobs} sqldocdir=%{_docdir}/%{name} sampledir=%{_docdir}/%{name}

%install
%makeinstall sqldocdir=%{_docdir}/%{name} sampledir=%{_docdir}/%{name}
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print
cp AUTHORS COPYING ChangeLog NEWS README COPYING $RPM_BUILD_ROOT%{_docdir}/%{name}
%find_lang %{name} %{?no_lang_C}
%find_gconf_schemas
%suse_update_desktop_file -N "Planner" -G "Project Management" -C "" planner
%fdupes -s $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%pre -f %{name}.schemas_pre

%post
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_post
%icon_theme_cache_post
%mime_database_post
%else
if test -x usr/bin/update-mime-database ; then
  usr/bin/update-mime-database usr/share/mime >/dev/null
fi
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun
%else
if test -x usr/bin/update-mime-database ; then
  usr/bin/update-mime-database usr/share/mime >/dev/null
fi
%endif

%posttrans -f %{name}.schemas_posttrans

%preun -f %{name}.schemas_preun

%files -f %{name}.schemas_list
%defattr(-, root, root)
%doc %{_docdir}/%{name}
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/48x48/mimetypes/*.png
%{_datadir}/mime/packages/planner.xml
%{_datadir}/pixmaps/*.png
%{_libdir}/*.so.*
%{_libdir}/planner
%{_datadir}/planner
%{py_sitedir}/*.so
%doc %{_mandir}/man1/planner.1*
%exclude %{_libdir}/planner/plugins/libeds-plugin.so

%if %build_eds
%files evolution
%defattr(-, root, root)
%if %build_eds_backend
%{_libdir}/evolution-data-server-*/extensions/*.so*
%{_libdir}/evolution/*/plugins/*.so
%{_libdir}/evolution/*/plugins/*.eplug
%endif
%{_libdir}/planner/plugins/libeds-plugin.so
%endif

%files lang -f %{name}.lang

%files devel
%defattr(-, root, root)
%{_libdir}/pkgconfig/*.pc
%{_includedir}/planner-1.0
%{_libdir}/*.so
%{_datadir}/gtk-doc/html/libplanner
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html

%changelog
* Thu Mar 24 2016 dimstar@opensuse.org
- Add planner-gtk-1.25.patch: Do not install no-longer existing
  index.sgml file. This was in any case used internally by gtk-doc
  to produce the rest of the code.
* Mon Dec 16 2013 zaitor@opensuse.org
- Exchange scrollkeeper BuildRequires for
  rarian-scrollkeeper-compat. Scrollkeeper was dropped from
  distribution.
- Stop rm -r %%{buildroot}%%{_localstatedir}/scrollkeeper, after the
  switch to rarian-scrollkeper-compat it does not exist any more.
* Thu Mar 14 2013 dimstar@opensuse.org
- Disable long obsoleted libgda component:
  + Remove libgda-3_0-devel BuildRequires.
  + Change --with-database=auto configure parameter to =no.
  + Add libxslt-devel BuildRequires, which used to be pulled in by
    libgda-3_0-devel before.
* Tue Feb 26 2013 dimstar@opensuse.org
- Drop explicit Requires from planner-devel: gconf2-devel,
  glib2-devel, gnome-vfs2-devel, libgsf-devel, libxml2-devel: if
  they were needed, they would be pulled in by pkgconfig()-style
  requires.
* Mon Dec 17 2012 dimstar@opensuse.org
- Add build_eds defines, set to openSUSE <= 1220 (last version we
  had a compatible evolution version).
- If build_eds evaluates to false, then:
  + Pass --disable-eds to configure
  + Don't create the evolution subpackage
  + Obsolete the evolution subpackage from the main package.
  else pass --enable-eds to configure.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Thu Aug  9 2012 dimstar@opensuse.org
- Add planner-libgnome.patch: link libsql-plugin to libgnome
  (bnc#775189).
- Add gnome-common BuildRequires and call gnome-autogen.sh, as
  above patch touches the build system.
* Wed Aug  8 2012 dimstar@opensuse.org
- Add planner-cmdline.patch: Fix for broken "open file on startup"
  behaviour (bnc#774972, bgo#656373).
* Sat Dec 31 2011 zaitor@opensuse.org
- Update to version 0.14.6:
  + Fixed compilation with --with-database.
  + Several warnings fixed.
  + Got rid of AM_MAINTAINER_MODE.
  + Got rid of some deprecated code.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Oct  3 2011 vuntz@opensuse.org
- Add explicit shared-mime-info BuildRequires since we use the
  %%mime_database_* macros.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 0.14.5:
  + Minor build enhancements, gnome-common is now needed to build
  + Many memory leaks got fixed (bgo#334114, bgo#596746)
  + Some deprecated code got updated (bgo#349304, bgo#536416,
    bgo#584009, bgo#590485, bgo#613623)
  + Bugs fixed:
  - Crash when exporting HTML
  - Prevent changing order of resources on load/save
  - Crash when using zoom-to-fit (bgo#550559)
  - Assigned resources information shown in HTML export
    (bgo#308064)
  - Maximum percent complete stuck at 75%% (bgo#580216)
  - Error when opening files with colon in path (bgo#602427)
  - Allow scrolling in Gantt and resource usage (bgo#604355)
  - Show date in status bar (bgo#604515)
  + Updated translations.
- Drop planner-fix-build.patch: fixed upstream.
- Do not add Office and ProjectManagement categories to
  planner.desktop as those are already there.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Sep 10 2010 vuntz@opensuse.org
- Do not build the eds backend on 11.4 and later, since it fails to
  build there. There's no patch upstream to fix this,
  unfortunately.
- Also add missing libglade2-devel BuildRequires, that was brought
  implicitly by evolution-devel.
* Fri Jan 22 2010 vuntz@opensuse.org
- Add planner-fix-build.patch to fix build with latest
  evolution-data-server: we need to manually require libgnome-2.0.
- Version the Obsoletes of mrproject to avoid self-obsoletion.
- Update description of packages.
* Thu Apr 16 2009 vuntz@novell.com
- Update to version 0.14.4:
  + Rewrote printing to use the GTK printing API, fixing most
    problems with printing on Windows
  + Added display of minutes to duration format
  + Added creation of Windows installer to Makefiles
  + Dropped support for libgda < 3.0
  + Added proper quoting to SQL code (bgo#168147, bgo#571801)
  + Fixed alignment problems in HTML export (bgo#471218,
    bgo#478027)
  + Fixed a crash in UNDO/REDO code (#420443)
  + Fixed several issues with the build (bgo#528582, bgo#528971,
    bgo#529045, bgo#539993)
  + Updated translations.
- Drop planner-desktop.patch: we already do this via
  suse_update_desktop_file.
- Drop planner-evolution.patch, planner-e_utf8.patch,
  planner-python-util.patch, configure.patch: not needed anymore.
- Drop planner-bgo539993-buildfix.patch: fixed upstream.
- Remove unneeded BuildRequires: gnome-common,
  libgnomeprintui-devel, libgsf-devel, libidl-devel, libwnck-devel,
  mozilla-nss-devel, perl-XML-Parser
- Do not call autoreconf and intltoolize anymore.
- Fix configure flag for libgda from --enable-database to
  - -with-database.
- Re-enable the use of evolution-data-server (via configure), and
  create a planner-evolution package to not have planner always
  depend on evolution (instead of using some hack).
- Re-enable parallel build.
- Remove check for old version of openSUSE.
- Merge doc package in devel package since it only provided gtk-doc
  files.
- Do not package omf files twice.
- Rework the package list.
* Tue Feb 10 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Fri Feb  6 2009 hfiguiere@suse.de
- BuildRequires on libgda-3_0-devel.
* Wed Jan 28 2009 vuntz@novell.com
- BuildRequires on libgda-4_0-devel.
* Sat Jan 17 2009 crrodriguez@suse.de
- remove "la" files
* Tue Nov 11 2008 ro@suse.de
- really comment out unused triggers
* Fri Oct  3 2008 vuntz@novell.com
- Fix build:
  + Add planner-bgo539993-buildfix.patch taken from upstream svn.
  + Remove planner-gda3.patch which doesn't apply and isn't needed
    anymore.
  + Refresh configure.patch to remove unneeded gda changes.
  + Refresh planner-evolution.patch.
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.14.3:
  + Added support for version 3 of libgda, the database access
    library
  + Added internationalization (I18N) support for HTML export
  + Allow dragging of completion bar in Gantt chart
  + Allow dragging of task duration in Gantt beyond the window
    size
  + %% Complete column added to task and Gantt view
  + Show guide lines setting is now persistent
  + Bugs fixed: bgo#332748, bgo#337382, bgo#345163, bgo#373008,
    bgo#382548, bgo#388454, bgo#393620, bgo#397132, bgo#436263,
    bgo#464359, bgo#486990, and bgo#499090
  + Updated translations.
* Thu Mar  6 2008 maw@suse.de
- Fix the build when against newer versions of intltool.
* Thu Jan 31 2008 sbrabec@suse.cz
- Devhelp documentation moved to the separate package (bnc#248813).
* Thu Oct 18 2007 sbrabec@suse.cz
- Build with libgda-3.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Fri Aug 10 2007 coolo@suse.de
- define Version before the use of %%version
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun.
* Thu Jul 26 2007 maw@suse.de
- Update to version 0.14.2:
  + Fixes for bugzilla.gnome.org bugs fixed: #353232, #368186,
    [#353213], and #358415
  + Minor build changes
  + Updated translations
- Add evolution-data-server-devel, fdupes, libgnomecanvas-devel,
  libgnomeui-devel, and libgnomeprintui-devel as build requirements
- Add configure.patch
- Use fdupes
- For the present, don't build the evolution backend.
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Mon Mar 19 2007 sbrabec@suse.cz
- Build with evolution-2.10.
* Mon Feb 19 2007 sbrabec@suse.cz
- Fixed broken scriptlets.
* Thu Jan  4 2007 sbrabec@suse.cz
- Build correctly in older products.
* Wed Jan  3 2007 sbrabec@suse.cz
- Spec file cleanup.
* Wed Jan  3 2007 maw@suse.de
- Move to /usr.
* Mon Dec 11 2006 sbrabec@suse.cz
- Define correct %%mandir.
* Mon Dec  4 2006 jhargadon@suse.de
- removed unneeded files (#225778)
* Thu Nov  9 2006 jhargadon@suse.de
- added "intltoolize --copy --force --automake" to the specfile
  so fix a problem with translations. (219388)
* Tue Oct 17 2006 jhargadon@suse.de
- update to version 0.14.1
- new man page contributed by Martin-Eric Racine
- fix for bug #353213
- corrected build of translated user guides
- src/planner-format.c:  fix NULL pointer deref - bug #334121
- src/planner-gantt-row.c:  patch to fix segv on scrolling - bug #345517
- po/POTFILES.in:  Added missing files per bug #344793
* Mon Sep 25 2006 jhargadon@suse.de
- update to version 0.14
- po/POTFILES.in: Removed referece to planner.keys.in
- python/Makefile.am: Correct error when builddir != srcdir
- src/planner-window.c: Change planner homepage in about box to
  live.gnome.org/Planner
- Updated user guide
- Changed 'Hint' lines to 'Guide' Lines
- Shows horizontal lines on Gantt to help line up task tree with chart
- added %%py_requires to the specfile to resolve bug #207924
* Mon Sep  4 2006 ro@suse.de
- patch configure for e-d-s-1.8
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
* Mon Mar 13 2006 jpr@suse.de
- Fix build by removing an additional generated mime file
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 17 2006 gekker@suse.de
- Update .desktop file for UI team
* Mon Feb 13 2006 vvaradhan@novell.com
- Fix to build with evolution-2.5 (aka 2.6)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 jpr@suse.de
- Don't look for gettext message domains that don't exist
* Mon Oct 17 2005 sbrabec@suse.cz
- Fixed opt plugin triggers.
* Thu Oct  6 2005 sbrabec@suse.cz
- Don't depend on evolution, use trigger for plugin (#104878).
- Fixed broken python plugin linking.
* Sat Aug 13 2005 gekker@suse.de
- Fix to build with new libgda
* Mon Aug  1 2005 sbrabec@suse.cz
- Build with latest evolution (link with emiscwidgets).
* Fri Jul 29 2005 sbrabec@suse.cz
- Build with kerberos-devel-packages.
* Wed Jul 13 2005 sbrabec@suse.cz
- Build with current version of libgda and evolution.
- Removed unneeded static modules and .la files for modules.
- Branched devel subpackage.
* Wed Jun  8 2005 ro@suse.de
- wildcard for python version
* Tue May  3 2005 pmladek@suse.cz
- added mozilla-nss mozilla-nss-devel to fix build
* Tue Apr  5 2005 sbrabec@suse.cz
- Updated to version 0.13 (#71967).
- Enabled optional plugins.
- Build as user.
* Tue Mar 22 2005 ro@suse.de
- fix build by removing more generated mime files
* Wed Mar 16 2005 clahey@suse.de
- Degeneralize menu item.
* Thu Mar 10 2005 ke@suse.de
- Make use of German translations coming with the 0.12.94 pre-release.
- Fix translation for the .desktop file; reported by Joachim Werner
  [#71895].
* Mon Nov  1 2004 mmj@suse.de
- Locale rename no to nb
* Fri Aug 27 2004 clahey@suse.de
- Cache planner help and show planner in khelpcenter.
* Thu Aug 26 2004 sbrabec@suse.cz
- Fixed shared mime installation according to bug #44182.
* Thu Aug 12 2004 ro@suse.de
- update filelist
* Mon Aug  9 2004 sagarwal@suse.de
- Upgraded the version of planner from 0.11 to 0.12.
* Mon Jun 21 2004 sagarwal@suse.de
- Fixed bug #59012, file chaned src/planner-gantt-print.c
* Mon Jun 21 2004 sagarwal@suse.de
- Fixed bug #59015, file changed src/planner-html-plugin.c
* Wed May 12 2004 clahey@suse.de
- Switched from mrproject to planner.
* Sat Mar  6 2004 ro@suse.de
- move build macro before first make install
* Sat Aug 16 2003 adrian@suse.de
- add Categories
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Sat Jun 28 2003 coolo@suse.de
- package directories
- use %%find_lang
* Thu Jun  5 2003 ro@suse.de
- added unpackaged files (mostly small devel stuff) to filelist
* Mon Apr 28 2003 adrian@suse.de
- add libgsf-gnome to #neededforbuild
* Wed Feb 26 2003 hhetter@suse.de
- fix build, really link any plugin
- fix scrollkeeper usage, and build help docs
- updated to bugfix-only release 0.9.1
* Tue Feb 18 2003 adrian@suse.de
- fix build
* Mon Feb 17 2003 adrian@suse.de
- update to version 0.9
* Mon Feb 17 2003 hhetter@suse.de
- updated to stable bugfix release 0.8 (+library)
- filelist fix
* Thu Jan 16 2003 ro@suse.de
- use "gtk2-devel-packages,libjpeg" in neededforbuild
* Tue Jan 14 2003 ro@suse.de
- added expat to neededforbuild
* Wed Sep 25 2002 sf@suse.de
- added alsa-devel to neededforbuild
- fixed some biarch-prblems in .spec to build those Archs
* Mon Sep 23 2002 hhetter@suse.de
- build with alsa support
* Thu Aug 15 2002 hhetter@suse.de
- updated to GNOME 2 port of mrproject: version 0.6
- complete filelist rework
* Thu Jun 20 2002 ro@suse.de
- use "-a -f" for automake
* Mon Jun  3 2002 ro@suse.de
- use "gnome-devel-packages" in neededforbuild
* Tue Mar  5 2002 hhetter@suse.de
- fixed filelist and permissions (close Bug Id#14268)
- really build with automake 1.5
- use buildroot
- enable evolution mail component
- functionality test on i386
* Tue Dec 18 2001 hhetter@suse.de
- updated to version 0.5.0
  * translation updates
  * sorting in allocation table fixed
  * improvements to calendar component
* Wed Nov 21 2001 ro@suse.de
- added freetype2 to neededforbuild
* Wed Oct 24 2001 hhetter@suse.de
- updated to 0.4.0
  * Network diagram component
  * Calendar component
  * Progress tracking
  * Draw fixes in Gantt component
  * New icons
  * Better navigation in Gantt (right-click-menu)
  * Simple man pages
  * Various bug fixes
- prefixed to /opt/gnome
- enabled python module
- functionality test on i386
* Thu Oct 11 2001 sf@suse.de
- added missing parameters in function call to compile with gcc > 2.95.x
* Thu Jul  5 2001 kkaempf@suse.de
- Initial version 0.3.2
